@@ -137,6 +137,12 @@ plot.trellis <-
 
 
 
+panel.error <- function(e)
+{
+    grid.text(gettextf("Error using packet %g\n%s",
+                       panel.number(),
+                       conditionMessage(e)))
+}
 
 
 
@@ -152,9 +158,14 @@ print.trellis <-
              panel.height = lattice.getOption("layout.heights")$panel,
              panel.width = lattice.getOption("layout.widths")$panel,
              save.object = lattice.getOption("save.object"),
+             panel.error = lattice.getOption("panel.error"),
              prefix = NULL,
              ...)
 {
+    panel.error <-
+        if (is.function(panel.error)) panel.error 
+        else if (is.character(panel.error)) get(panel.error)
+        else eval(panel.error)
 
     ## save the current object, if so requested.  This used to be done
     ## at the end, so that it wouldn't happen if there were errors
@@ -216,6 +227,7 @@ print.trellis <-
         if ("panel.height" %in% supplied && missing(panel.height)) panel.height <- x$plot.args$panel.height
         if ("panel.width"  %in% supplied && missing(panel.width))  panel.width  <- x$plot.args$panel.width
         if ("save.object"  %in% supplied && missing(save.object))  save.object  <- x$plot.args$save.object
+        if ("panel.error"  %in% supplied && missing(panel.error))  panel.error  <- x$plot.args$panel.error
         if ("prefix"       %in% supplied && missing(prefix))       prefix       <- x$plot.args$prefix
     }
 
@@ -572,7 +584,6 @@ print.trellis <-
     ## this layout will now be used for each page (this is quite
     ## complicated and unfortunately very convoluted)
 
-
     layoutCalculations <-
         calculateGridLayout(x,
                             rows.per.page, cols.per.page,
@@ -586,6 +597,9 @@ print.trellis <-
                             xaxis.cex, yaxis.cex,
                             par.strip.text,
                             legend)
+    lattice.setStatus(layout.details = layoutCalculations)
+    lattice.setStatus(as.table = x$as.table)
+
     page.layout <- layoutCalculations$page.layout
     pos.heights <- layoutCalculations$pos.heights
     pos.widths <- layoutCalculations$pos.widths
@@ -1004,7 +1018,8 @@ print.trellis <-
 
                         if (!("..." %in% names(formals(panel))))
                             pargs <- pargs[names(formals(panel))]
-                        do.call("panel", pargs)
+                        tryCatch(do.call("panel", pargs),
+                                 error = function(e) panel.error(e))
 
                         upViewport()
 
@@ -1155,21 +1170,23 @@ print.trellis <-
                                                    name = trellis.vpname("legend", side = "bottom"))),
                            inside = {
 
-                               ## FIXME: there are two choices here
-                               ## --- either treat the whole figure
-                               ## region as the rectangle, or use just
-                               ## the region covered by the panels.
-                               ## Currently, the first is done.
-                               ## Ideally, it should be
-                               ## user-controllable, presumably
-                               ## through lattice.options().  Easy to
-                               ## do, just need to figure out the
-                               ## limits.  Just not feeling
-                               ## enthusiastic enough right now.
+                               ## There are two choices here ---
+                               ## either treat the whole figure region
+                               ## as the rectangle, or use just the
+                               ## region covered by the panels.  This
+                               ## is user-controllable through
+                               ## lattice.options("legend.bbox").
 
-                               pushViewport(viewport(layout.pos.row = c(1, n.row),
-                                                     layout.pos.col = c(1, n.col),
-                                                     name = trellis.vpname("legend", side = "inside")))
+                               legend.bbox <- lattice.getOption("legend.bbox")
+                               switch(legend.bbox,
+                                      full = 
+                                      pushViewport(viewport(layout.pos.row = c(1, n.row),
+                                                            layout.pos.col = c(1, n.col),
+                                                            name = trellis.vpname("legend", side = "inside"))),
+                                      panel =
+                                      pushViewport(viewport(layout.pos.row = range(pos.heights$panel, pos.heights$strip),
+                                                            layout.pos.col = range(pos.widths$panel, pos.widths$strip.left),
+                                                            name = trellis.vpname("legend", side = "inside"))))
                                key.corner <-
                                    if (is.null(legend[[i]]$corner)) c(0,1)
                                    else legend[[i]]$corner
@@ -1179,49 +1196,10 @@ print.trellis <-
                                key.y <- 
                                    if (is.null(legend[[i]]$y)) key.corner[2]
                                    else legend[[i]]$y
-                               if (all(key.corner == c(0,1)))
-                               {
-                                   pushViewport(viewport(layout = grid.layout(nrow = 3, ncol = 3,
-                                                         widths = unit(c(key.x, 1, 1),
-                                                         c("npc", "grobwidth", "null"),
-                                                         list(NULL, key.gf, NULL)),
-                                                         heights = unit(c(1 - key.y, 1, 1),
-                                                         c("npc", "grobheight", "null"),
-                                                         list(NULL, key.gf, NULL)))))
-                               }
-                               else if (all(key.corner == c(1,1)))
-                               {
-                                   pushViewport(viewport(layout = grid.layout(nrow = 3, ncol = 3,
-                                                         heights = unit(c(1 - key.y, 1, 1),
-                                                         c("npc", "grobheight", "null"),
-                                                         list(NULL, key.gf, NULL)),
-                                                         widths = unit(c(1, 1, 1 - key.x),
-                                                         c("null", "grobwidth", "npc"),
-                                                         list(NULL, key.gf, NULL)))))
-                               }
-                               else if (all(key.corner == c(0,0)))
-                               {
-                                   pushViewport(viewport(layout = grid.layout(nrow = 3, ncol = 3,
-                                                         widths = unit(c(key.x, 1, 1),
-                                                         c("npc", "grobwidth", "null"),
-                                                         list(NULL, key.gf, NULL)),
-                                                         heights = unit(c(1, 1, key.y),
-                                                         c("null", "grobheight", "npc"),
-                                                         list(NULL, key.gf, NULL)))))
-                               }
-                               else if (all(key.corner == c(1,0)))
-                               {
-                                   pushViewport(viewport(layout=grid.layout(nrow = 3, ncol = 3,
-                                                         widths = unit(c(1, 1, 1 - key.x),
-                                                         c("null", "grobwidth", "npc"),
-                                                         list(NULL, key.gf, NULL)),
-                                                         heights = unit(c(1, 1, key.y),
-                                                         c("null", "grobheight", "npc"),
-                                                         list(NULL, key.gf, NULL)))))
-                               }
                                drawInViewport(key.gf,
-                                              viewport(layout.pos.row = 2, layout.pos.col = 2))
-                               upViewport(2)
+                                              viewport(x = unit(key.x, "npc") + unit(0.5 - key.corner[1], "grobwidth", list(key.gf)),
+                                                       y = unit(key.y, "npc") + unit(0.5 - key.corner[2], "grobheight", list(key.gf))))
+                               upViewport(1)
                            })
                        }
                 }
